@@ -1,9 +1,8 @@
 testthat::context("test-extract_points")
 
-landscape_classified <- shar::classify_habitats(shar::landscape, classes = 5)
+landscape_classified <- classify_habitats(landscape, classes = 5)
 
-points_df <- shar::extract_points(raster = landscape_classified,
-                                  pattern = shar::species_b)
+points_df <- extract_points(raster = landscape_classified, pattern = species_b)
 
 ################################################################################
 
@@ -17,5 +16,5 @@ testthat::test_that("extract_points counts all points present in the landscape",
 
   extracted_points <- sum(points_df$count)
 
-  testthat::expect_equal(extracted_points, expected = shar::species_b$n)
+  testthat::expect_equal(extracted_points, expected = species_b$n)
 })
