@@ -1,19 +1,21 @@
 testthat::context("test-randomize_raster")
 
-landscape_classified <- shar::classify_habitats(raster = shar::landscape,
-                                                classes = 5)
+landscape_classified <- classify_habitats(raster = landscape, classes = 5)
 
 # normal random
-landscape_random <- shar::randomize_raster(raster = landscape_classified,
-                                           n_random = 1,
-                                           verbose = FALSE)
+landscape_random <- randomize_raster(raster = landscape_classified, n_random = 1,
+                                     verbose = FALSE)
 
 # simplify output
-raster_random_simple <- shar::randomize_raster(raster = landscape_classified,
-                                               n_random = 1,
-                                               simplify = TRUE,
-                                               return_input = FALSE,
-                                               verbose = FALSE)
+raster_random_simple <- randomize_raster(raster = landscape_classified, n_random = 1,
+                                         simplify = TRUE, return_input = FALSE,
+                                         verbose = FALSE)
+
+# create landscape wrong extent
+landscape_wrong <- landscape_classified
+
+# classify landscape wrong extent
+landscape_wrong[1:50] <- NA
 
 ################################################################################
 
@@ -49,30 +51,31 @@ testthat::test_that("simplify works for randomize_raster", {
 
 testthat::test_that("randomize_raster returns error of n_random < 1", {
 
-  testthat::expect_error(shar::randomize_raster(raster = landscape_classified,
-                                                n_random = 0,
-                                                verbose = FALSE),
+  testthat::expect_error(randomize_raster(raster = landscape_classified, n_random = 0,
+                                          verbose = FALSE),
                          regexp = "n_random must be >= 1.",
                          fixed = TRUE)
 })
 
 testthat::test_that("randomize_raster returns all warnings", {
 
-  testthat::expect_warning(shar::randomize_raster(raster = landscape_classified,
-                                                  n_random = 1,
-                                                  simplify = TRUE),
+  testthat::expect_warning(randomize_raster(raster = landscape_classified, n_random = 1,
+                                            simplify = TRUE),
                            regexp = "'simplify = TRUE' not possible for 'return_input = TRUE'.",
                            fixed = TRUE)
 
-  testthat::expect_warning(shar::randomize_raster(raster = landscape_classified,
-                                                  n_random = 2,
-                                                  simplify = TRUE,
-                                                  return_input = FALSE),
+  testthat::expect_warning(randomize_raster(raster = landscape_classified, n_random = 2,
+                                            simplify = TRUE, return_input = FALSE),
                            regexp = "'simplify = TRUE' not possible for 'n_random > 1'.",
                            fixed = TRUE)
 
-  testthat::expect_warning(shar::randomize_raster(raster = landscape,
-                                                  n_random = 1),
+  testthat::expect_warning(randomize_raster(raster = landscape, n_random = 1),
                            regexp = "The raster has more than 10 classes. Please make sure discrete classes are provided.",
                            fixed = TRUE)
 })
+
+testthat::test_that("Warning if NA are present", {
+
+  testthat::expect_warning(randomize_raster(raster = landscape_wrong, n_random = 1),
+                         regexp = "NA values present. Please make sure the observation window of the point pattern reflects this.")
+})
